@@ -41,13 +41,16 @@ def echo(*args, **kwargs) -> None:
         the `--json` flag.
 
     """
+    if os.getenv("SILENCE_OUTPUT", "false") == "true":
+        return
+
     click_ctx = click.get_current_context(silent=True)
 
     if click_ctx is None:
         return click.echo(*args, **kwargs)
 
     json_flag = click_ctx.params.get("json_flag")
-    if json_flag and json_flag is not None:
+    if json_flag is not None and json_flag:
         return
     else:
         return click.echo(*args, **kwargs)
@@ -171,6 +174,7 @@ def install(
     cloud: bool,
     dev_mode: bool,
     no_argo: bool,
+    no_nginx: bool,
     fqdn: t.Optional[str],
     socket_path: t.Optional[str],
     userdir_pvc_size: int,
@@ -311,9 +315,18 @@ def install(
     metadata = {
         "name": cluster_name,
         "namespace": ns,
+        "annotations": {},
     }
     if socket_path is not None:
-        metadata["annotations"] = {"orchest.io/container-runtime-socket": socket_path}
+        metadata["annotations"]["orchest.io/container-runtime-socket"] = socket_path
+
+    if no_nginx:
+        echo(
+            "Disabling 'Nginx Ingress Controller' installation."
+            "\n\tMake sure 'Nginx Ingress Controller' is already installed "
+            "in your cluster"
+        )
+        metadata["annotations"]["controller.orchest.io/deploy-ingress"] = "false"
 
     applications = [
         {
@@ -1240,8 +1253,8 @@ def _run_pod_exec(
         if status != ClusterStatus.RUNNING:
             reason = (
                 "The Orchest Cluster state is "
-                " '{'unknown' if status is None else status.value}', whereas it needs"
-                " to be '{ClusterStatus.RUNNING.value}'. Check:"
+                f" '{'unknown' if status is None else status.value}', whereas it needs"
+                f" to be '{ClusterStatus.RUNNING.value}'. Check:"
                 "\n\torchest status"
             )
             return False, reason
